libtemplate package
===================

Submodules
----------

libtemplate.cli module
----------------------

.. automodule:: libtemplate.cli
   :members:
   :undoc-members:
   :show-inheritance:

libtemplate.dummy module
------------------------

.. automodule:: libtemplate.dummy
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: libtemplate
   :members:
   :undoc-members:
   :show-inheritance:
